@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 FreeIPMI Core Team
+ * Copyright (C) 2003-2015 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,9 +27,11 @@
 #include "freeipmi/cmds/ipmi-oem-intel-node-manager-cmds.h"
 #include "freeipmi/fiid/fiid.h"
 #include "freeipmi/spec/ipmi-channel-spec.h"
-#include "freeipmi/spec/ipmi-cmd-oem-spec.h"
+#include "freeipmi/spec/oem/ipmi-cmd-oem-intel-node-manager-spec.h"
 #include "freeipmi/spec/ipmi-iana-enterprise-numbers-spec.h"
 
+#include "freeipmi/spec/oem/ipmi-cmd-oem-intel-node-manager-spec.h"
+
 #include "libcommon/ipmi-fiid-util.h"
 #include "libcommon/ipmi-fill-util.h"
 #include "libcommon/ipmi-trace.h"
@@ -40,17 +42,6 @@
  * Intel                                   *
  *******************************************/
 
-/*
- * Intel Node Manager
- *
- * For Intel Chips, not just Intel Motherboards.  Confirmed for:
- *
- * Intel S5500WB/Penguin Computing Relion 700
- * Inventec 5441/Dell Xanadu II
- * Inventec 5442/Dell Xanadu III
- * Quanta S99Q/Dell FS12-TY
- */
-
 fiid_template_t tmpl_cmd_oem_intel_node_manager_enable_disable_node_manager_policy_control_rq =
   {
     { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -85,7 +76,34 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_policy_rq =
     { 1,  "policy_storage_option", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 1,  "policy_exception_actions.send_alert", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 1,  "policy_exception_actions.shutdown_system", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 6,  "policy_exception_actions.reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 5,  "policy_exception_actions.reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_power_domain", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 16, "policy_target_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 32, "correction_time_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 16, "policy_trigger_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 16, "statistics_reporting_period", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_policy_boot_time_policy_rq =
+  {
+    { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4,  "domain_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_enabled", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 3,  "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "policy_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4,  "policy_trigger_type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_configuration_action", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 2,  "aggressive_cpu_power_correction", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_storage_option", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_exception_actions.send_alert", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_exception_actions.shutdown_system", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 5,  "policy_exception_actions.reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_power_domain", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_target_limit.platform_booting_mode", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 7,  "policy_target_limit.cores_disabled", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "policy_target_limit.reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED}, 
     { 16, "policy_target_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 32, "correction_time_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 16, "policy_trigger_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -127,7 +145,8 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_policy_rs =
     { 1,  "policy_storage_option", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 1,  "policy_exception_actions.send_alert", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 1,  "policy_exception_actions.shutdown_system", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 6,  "policy_exception_actions.reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 5,  "policy_exception_actions.reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_power_domain", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     /* listed as "power limit" in 2.0 spec but "policy target limit"
      * in set version.  changing to 'policy target limit' to be
      * consistent
@@ -143,7 +162,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_policy_rs =
  * threshold is 2 bytes and there is a max of 3, so I list as the
  * entries and make them optional
  */
-fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_thresholds_rq =
+fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_policy_alert_thresholds_rq =
   {
     { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -157,7 +176,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_threshold
     { 0, "", 0}
   };
 
-fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_thresholds_rs =
+fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_policy_alert_thresholds_rs =
   {
     { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
     { 8,  "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
@@ -165,7 +184,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_threshold
     { 0, "", 0}
   };
 
-fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_alert_thresholds_rq =
+fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_policy_alert_thresholds_rq =
   {
     { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -179,7 +198,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_alert_threshold
  * threshold is 2 bytes and there is a max of 3, so I list the
  * entries and make them optional
  */
-fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_alert_thresholds_rs =
+fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_policy_alert_thresholds_rs =
   {
     { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
     { 8,  "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
@@ -391,7 +410,8 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_capabilities_rq
     { 4,  "domain_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "policy_trigger_type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 4,  "policy_type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 3,  "policy_type", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "policy_power_domain", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 0, "", 0}
   };
 
@@ -458,7 +478,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_destinati
     { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "channel_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 3,  "reserved1", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 1,  "destination_information_operation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "alert_receiver_deactivation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 8,  "destination_information", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 7,  "alert_string_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 1,  "send_alert_string", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -471,7 +491,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_destinati
     { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "channel_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 3,  "reserved1", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 1,  "destination_information_operation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "alert_receiver_deactivation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 1,  "reserved2", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 7,  "slave_address", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 7,  "alert_string_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -485,7 +505,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_destinati
     { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "channel_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 3,  "reserved1", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 1,  "destination_information_operation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "alert_receiver_deactivation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "destination_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "reserved2", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 7,  "alert_string_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -515,7 +535,7 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_alert_destinati
     { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "channel_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 3,  "reserved1", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
-    { 1,  "destination_information_operation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 1,  "alert_receiver_deactivation", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "destination_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 4,  "reserved2", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
     { 7,  "alert_string_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -523,6 +543,45 @@ fiid_template_t tmpl_cmd_oem_intel_node_manager_get_node_manager_alert_destinati
     { 0, "", 0}
   };
 
+fiid_template_t tmpl_cmd_oem_intel_node_manager_set_turbo_synchronization_ratio_rq =
+  {
+    { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "cpu_socket_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "active_cores_configuration", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "turbo_ratio_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_oem_intel_node_manager_set_turbo_synchronization_ratio_rs =
+  {
+    { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8,  "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_oem_intel_node_manager_get_turbo_synchronization_ratio_rq =
+  {
+    { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "cpu_socket_number", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "active_cores_configuration", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_oem_intel_node_manager_get_turbo_synchronization_ratio_rs =
+  {
+    { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8,  "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 24, "manufacturer_id", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "current_turbo_ratio_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "default_turbo_ratio_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "maximum_turbo_ratio_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8,  "minimum_turbo_ratio_limit", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 0, "", 0}
+  };
+ 
 fiid_template_t tmpl_cmd_oem_intel_node_manager_get_limiting_policy_id_rq =
   {
     { 8,  "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -584,6 +643,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_policy (uint8_t domain_id,
 							 uint8_t policy_storage_option,
                                                          uint8_t policy_exception_actions_send_alert,
                                                          uint8_t policy_exception_actions_shutdown_system,
+							 uint8_t policy_power_domain,
                                                          uint16_t policy_target_limit,
                                                          uint32_t correction_time_limit,
                                                          uint16_t policy_trigger_limit,
@@ -598,6 +658,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_policy (uint8_t domain_id,
       || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_STORAGE_VALID (policy_storage_option)
       || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_EXCEPTION_ACTION_VALID (policy_exception_actions_send_alert)
       || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_EXCEPTION_ACTION_VALID (policy_exception_actions_shutdown_system)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_POWER_DOMAIN_VALID (policy_power_domain)
       || !fiid_obj_valid (obj_cmd_rq))
     {
       SET_ERRNO (EINVAL);
@@ -625,6 +686,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_policy (uint8_t domain_id,
   FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_exception_actions.send_alert", policy_exception_actions_send_alert);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_exception_actions.shutdown_system", policy_exception_actions_shutdown_system);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_exception_actions.reserved", 0);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_power_domain", policy_power_domain);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_target_limit", policy_target_limit);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "correction_time_limit", correction_time_limit);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_trigger_limit", policy_trigger_limit);
@@ -633,6 +695,72 @@ fill_cmd_oem_intel_node_manager_set_node_manager_policy (uint8_t domain_id,
   return (0);
 }
 
+int
+fill_cmd_oem_intel_node_manager_set_node_manager_policy_boot_time_policy (uint8_t domain_id,
+									  uint8_t policy_enabled,
+									  uint8_t policy_id,
+									  uint8_t policy_trigger_type,
+									  uint8_t policy_configuration_action,
+									  uint8_t aggressive_cpu_power_correction,
+									  uint8_t policy_storage_option,
+									  uint8_t policy_exception_actions_send_alert,
+									  uint8_t policy_exception_actions_shutdown_system,
+									  uint8_t policy_power_domain,
+									  uint8_t platform_booting_mode,
+									  uint8_t cores_disabled,
+									  uint32_t correction_time_limit,
+									  uint16_t policy_trigger_limit,
+									  uint16_t statistics_reporting_period,
+									  fiid_obj_t obj_cmd_rq)
+{
+  if (!IPMI_OEM_INTEL_NODE_MANAGER_DOMAIN_ID_VALID (domain_id)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_ENABLED_VALID (policy_enabled)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_TRIGGER_TYPE_VALID (policy_trigger_type)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_CONFIGURATION_ACTION_VALID (policy_configuration_action)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_AGGRESSIVE_CPU_POWER_CORRECTION_VALID (aggressive_cpu_power_correction)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_STORAGE_VALID (policy_storage_option)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_EXCEPTION_ACTION_VALID (policy_exception_actions_send_alert)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_EXCEPTION_ACTION_VALID (policy_exception_actions_shutdown_system)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_POWER_DOMAIN_VALID (policy_power_domain)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_PLATFORM_BOOTING_MODE_VALID (platform_booting_mode)
+      || !fiid_obj_valid (obj_cmd_rq))
+    {
+      SET_ERRNO (EINVAL);
+      return (-1);
+    }
+
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_oem_intel_node_manager_set_node_manager_policy_rq) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
+
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_OEM_INTEL_NODE_MANAGER_SET_NODE_MANAGER_POLICY);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "domain_id", domain_id);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_enabled", policy_enabled);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_id", policy_id);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_trigger_type", policy_trigger_type);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_configuration_action", policy_configuration_action);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "aggressive_cpu_power_correction", aggressive_cpu_power_correction);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_storage_option", policy_storage_option);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_exception_actions.send_alert", policy_exception_actions_send_alert);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_exception_actions.shutdown_system", policy_exception_actions_shutdown_system);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_exception_actions.reserved", 0);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_power_domain", policy_power_domain);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_target_limit.platform_booting_mode", platform_booting_mode);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_target_limit.cores_disabled", cores_disabled);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_target_limit.reserved", 0);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "correction_time_limit", correction_time_limit);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_trigger_limit", policy_trigger_limit);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "statistics_reporting_period", statistics_reporting_period);
+
+  return (0);
+}
+
 int
 fill_cmd_oem_intel_node_manager_get_node_manager_policy (uint8_t domain_id,
                                                          uint8_t policy_id,
@@ -663,12 +791,12 @@ fill_cmd_oem_intel_node_manager_get_node_manager_policy (uint8_t domain_id,
 }
 
 int
-fill_cmd_oem_intel_node_manager_set_node_manager_alert_thresholds (uint8_t domain_id,
-                                                                   uint8_t policy_id,
-                                                                   uint16_t *alert_threshold1,
-                                                                   uint16_t *alert_threshold2,
-                                                                   uint16_t *alert_threshold3,
-                                                                   fiid_obj_t obj_cmd_rq)
+fill_cmd_oem_intel_node_manager_set_node_manager_policy_alert_thresholds (uint8_t domain_id,
+									  uint8_t policy_id,
+									  uint16_t *alert_threshold1,
+									  uint16_t *alert_threshold2,
+									  uint16_t *alert_threshold3,
+									  fiid_obj_t obj_cmd_rq)
 {
   uint8_t number_of_alert_thresholds = 0;
 
@@ -679,7 +807,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_thresholds (uint8_t domai
       return (-1);
     }
 
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_oem_intel_node_manager_set_node_manager_alert_thresholds_rq) < 0)
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_oem_intel_node_manager_set_node_manager_policy_alert_thresholds_rq) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
@@ -687,7 +815,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_thresholds (uint8_t domai
 
   FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
 
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_OEM_INTEL_NODE_MANAGER_SET_NODE_MANAGER_ALERT_THRESHOLDS);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_OEM_INTEL_NODE_MANAGER_SET_NODE_MANAGER_POLICY_ALERT_THRESHOLDS);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "domain_id", domain_id);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
@@ -716,9 +844,9 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_thresholds (uint8_t domai
 }
 
 int
-fill_cmd_oem_intel_node_manager_get_node_manager_alert_thresholds (uint8_t domain_id,
-                                                                   uint8_t policy_id,
-                                                                   fiid_obj_t obj_cmd_rq)
+fill_cmd_oem_intel_node_manager_get_node_manager_policy_alert_thresholds (uint8_t domain_id,
+									  uint8_t policy_id,
+									  fiid_obj_t obj_cmd_rq)
 {
   if (!IPMI_OEM_INTEL_NODE_MANAGER_DOMAIN_ID_VALID (domain_id)
       || !fiid_obj_valid (obj_cmd_rq))
@@ -727,7 +855,7 @@ fill_cmd_oem_intel_node_manager_get_node_manager_alert_thresholds (uint8_t domai
       return (-1);
     }
 
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_oem_intel_node_manager_get_node_manager_alert_thresholds_rq) < 0)
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_oem_intel_node_manager_get_node_manager_policy_alert_thresholds_rq) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
@@ -735,7 +863,7 @@ fill_cmd_oem_intel_node_manager_get_node_manager_alert_thresholds (uint8_t domai
 
   FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
 
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_OEM_INTEL_NODE_MANAGER_GET_NODE_MANAGER_ALERT_THRESHOLDS);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_OEM_INTEL_NODE_MANAGER_GET_NODE_MANAGER_POLICY_ALERT_THRESHOLDS);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "domain_id", domain_id);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
@@ -1140,11 +1268,13 @@ int
 fill_cmd_oem_intel_node_manager_get_node_manager_capabilities (uint8_t domain_id,
                                                                uint8_t policy_trigger_type,
                                                                uint8_t policy_type,
+							       uint8_t policy_power_domain,
                                                                fiid_obj_t obj_cmd_rq)
 {
   if (!IPMI_OEM_INTEL_NODE_MANAGER_DOMAIN_ID_VALID (domain_id)
       || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_TRIGGER_TYPE_VALID (policy_trigger_type)
       || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_TYPE_VALID (policy_type)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_POLICY_POWER_DOMAIN_VALID (policy_power_domain)
       || !fiid_obj_valid (obj_cmd_rq))
     {
       SET_ERRNO (EINVAL);
@@ -1165,6 +1295,7 @@ fill_cmd_oem_intel_node_manager_get_node_manager_capabilities (uint8_t domain_id
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_trigger_type", policy_trigger_type);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_type", policy_type);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "policy_power_domain", policy_power_domain);
 
   return (0);
 }
@@ -1225,14 +1356,14 @@ fill_cmd_oem_intel_node_manager_set_node_manager_power_draw_range (uint8_t domai
 
 int
 fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination (uint8_t channel_number,
-                                                                    uint8_t destination_information_operation,
+                                                                    uint8_t alert_receiver_deactivation,
                                                                     uint8_t destination_information,
                                                                     uint8_t alert_string_selector,
                                                                     uint8_t send_alert_string,
                                                                     fiid_obj_t obj_cmd_rq)
 {
   if (!IPMI_CHANNEL_NUMBER_VALID (channel_number)
-      || !IPMI_OEM_INTEL_NODE_MANAGER_DESTINATION_INFORMATION_OPERATION_VALID (destination_information_operation)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_ALERT_RECEIVER_DEACTIVATION_VALID (alert_receiver_deactivation)
       || !IPMI_OEM_INTEL_NODE_MANAGER_ALERT_STRING_SELECTOR_VALID (alert_string_selector)
       || !IPMI_OEM_INTEL_NODE_MANAGER_SEND_ALERT_STRING_VALID (send_alert_string)
       || !fiid_obj_valid (obj_cmd_rq))
@@ -1253,7 +1384,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination (uint8_t chan
   FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "channel_number", channel_number);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved1", 0);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "destination_information_operation", destination_information_operation);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "alert_receiver_deactivation", alert_receiver_deactivation);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "destination_information", destination_information);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "alert_string_selector", alert_string_selector);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "send_alert_string", send_alert_string);
@@ -1263,14 +1394,14 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination (uint8_t chan
 
 int
 fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination_ipmb (uint8_t channel_number,
-                                                                         uint8_t destination_information_operation,
+                                                                         uint8_t alert_receiver_deactivation,
                                                                          uint8_t slave_address,
                                                                          uint8_t alert_string_selector,
                                                                          uint8_t send_alert_string,
                                                                          fiid_obj_t obj_cmd_rq)
 {
   if (!IPMI_CHANNEL_NUMBER_VALID (channel_number)
-      || !IPMI_OEM_INTEL_NODE_MANAGER_DESTINATION_INFORMATION_OPERATION_VALID (destination_information_operation)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_ALERT_RECEIVER_DEACTIVATION_VALID (alert_receiver_deactivation)
       || !IPMI_OEM_INTEL_NODE_MANAGER_ALERT_STRING_SELECTOR_VALID (alert_string_selector)
       || !IPMI_OEM_INTEL_NODE_MANAGER_SEND_ALERT_STRING_VALID (send_alert_string)
       || !fiid_obj_valid (obj_cmd_rq))
@@ -1291,7 +1422,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination_ipmb (uint8_t
   FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "channel_number", channel_number);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved1", 0);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "destination_information_operation", destination_information_operation);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "alert_receiver_deactivation", alert_receiver_deactivation);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved2", 0);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "slave_address", slave_address);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "alert_string_selector", alert_string_selector);
@@ -1302,14 +1433,14 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination_ipmb (uint8_t
   
 int
 fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination_lan (uint8_t channel_number,
-                                                                        uint8_t destination_information_operation,
+                                                                        uint8_t alert_receiver_deactivation,
                                                                         uint8_t destination_selector,
                                                                         uint8_t alert_string_selector,
                                                                         uint8_t send_alert_string,
                                                                         fiid_obj_t obj_cmd_rq)
 {
   if (!IPMI_CHANNEL_NUMBER_VALID (channel_number)
-      || !IPMI_OEM_INTEL_NODE_MANAGER_DESTINATION_INFORMATION_OPERATION_VALID (destination_information_operation)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_ALERT_RECEIVER_DEACTIVATION_VALID (alert_receiver_deactivation)
       || !IPMI_OEM_INTEL_NODE_MANAGER_ALERT_STRING_SELECTOR_VALID (alert_string_selector)
       || !IPMI_OEM_INTEL_NODE_MANAGER_SEND_ALERT_STRING_VALID (send_alert_string)
       || !fiid_obj_valid (obj_cmd_rq))
@@ -1330,7 +1461,7 @@ fill_cmd_oem_intel_node_manager_set_node_manager_alert_destination_lan (uint8_t
   FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "channel_number", channel_number);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved1", 0);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "destination_information_operation", destination_information_operation);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "alert_receiver_deactivation", alert_receiver_deactivation);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "destination_selector", destination_selector);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved2", 0);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "alert_string_selector", alert_string_selector);
@@ -1362,6 +1493,66 @@ fill_cmd_oem_intel_node_manager_get_node_manager_alert_destination (fiid_obj_t o
   return (0);
 }
 
+int
+fill_cmd_oem_intel_node_manager_set_turbo_synchronization_ratio (uint8_t cpu_socket_number,
+								 uint8_t active_cores_configuration,
+								 uint8_t turbo_ratio_limit,
+								 fiid_obj_t obj_cmd_rq)
+{
+  if (!IPMI_OEM_INTEL_NODE_MANAGER_CPU_SOCKET_VALID (cpu_socket_number)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_SET_ACTIVE_CORES_CONFIGURATION_VALID (active_cores_configuration)
+      || !fiid_obj_valid (obj_cmd_rq))
+    {
+      SET_ERRNO (EINVAL);
+      return (-1);
+    }
+
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_oem_intel_node_manager_set_turbo_synchronization_ratio_rq) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
+
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_OEM_INTEL_NODE_MANAGER_SET_TURBO_SYNCHRONIZATION_RATIO);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "cpu_socket_number", cpu_socket_number);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "active_cores_configuration", active_cores_configuration);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "turbo_ratio_limit", turbo_ratio_limit);
+
+  return (0);
+}
+
+int
+fill_cmd_oem_intel_node_manager_get_turbo_synchronization_ratio (uint8_t cpu_socket_number,
+								 uint8_t active_cores_configuration,
+								 fiid_obj_t obj_cmd_rq)
+{
+  if (!IPMI_OEM_INTEL_NODE_MANAGER_CPU_SOCKET_VALID (cpu_socket_number)
+      || !IPMI_OEM_INTEL_NODE_MANAGER_GET_ACTIVE_CORES_CONFIGURATION_VALID (active_cores_configuration)
+      || !fiid_obj_valid (obj_cmd_rq))
+    {
+      SET_ERRNO (EINVAL);
+      return (-1);
+    }
+
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_oem_intel_node_manager_get_turbo_synchronization_ratio_rq) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
+
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_OEM_INTEL_NODE_MANAGER_GET_TURBO_SYNCHRONIZATION_RATIO);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "manufacturer_id", IPMI_IANA_ENTERPRISE_ID_INTEL);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "cpu_socket_number", cpu_socket_number);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "active_cores_configuration", active_cores_configuration);
+
+  return (0);
+}
+
 int
 fill_cmd_oem_intel_node_manager_get_limiting_policy_id (uint8_t domain_id,
 							fiid_obj_t obj_cmd_rq)
