@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 FreeIPMI Core Team
+ * Copyright (C) 2003-2015 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 /*****************************************************************************\
  *  $Id: ipmi-fru.c,v 1.17 2010-02-08 22:09:40 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2014 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2015 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -1296,7 +1296,9 @@ _read_multirecord_area_data (ipmi_fru_ctx_t ctx,
       (*area_type) = IPMI_FRU_AREA_TYPE_MULTIRECORD_EXTENDED_DC_LOAD;
       break;
     default:
-      if (IPMI_FRU_MULTIRECORD_AREA_TYPE_IS_OEM (record_type_id))
+      if (IPMI_FRU_MULTIRECORD_AREA_TYPE_IS_NVM_EXPRESS (record_type_id))
+	(*area_type) = IPMI_FRU_AREA_TYPE_MULTIRECORD_NVM_EXPRESS;
+      else if (IPMI_FRU_MULTIRECORD_AREA_TYPE_IS_OEM (record_type_id))
 	(*area_type) = IPMI_FRU_AREA_TYPE_MULTIRECORD_OEM;
       else
 	(*area_type) = IPMI_FRU_AREA_TYPE_MULTIRECORD_UNKNOWN;
