@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 FreeIPMI Core Team
+ * Copyright (C) 2003-2015 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -216,6 +216,11 @@ extern "C" {
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DTN           IPMI_SUPERMICRO_PRODUCT_ID_FOUR_BASE
 #define IPMI_SUPERMICRO_PRODUCT_ID_X7SBI_LN4       IPMI_SUPERMICRO_PRODUCT_ID_FOUR_BASE
 
+#define IPMI_SUPERMICRO_PRODUCT_ID_PEPPERCON_X7DBR_3    IPMI_SUPERMICRO_PRODUCT_ID_X7DBR_3
+#define IPMI_SUPERMICRO_PRODUCT_ID_PEPPERCON_X7DB8      IPMI_SUPERMICRO_PRODUCT_ID_X7DB8
+#define IPMI_SUPERMICRO_PRODUCT_ID_PEPPERCON_X8DTN      IPMI_SUPERMICRO_PRODUCT_ID_X8DTN
+#define IPMI_SUPERMICRO_PRODUCT_ID_PEPPERCON_X7SBI_LN4  IPMI_SUPERMICRO_PRODUCT_ID_X7SBI_LN4
+
 /* Seen in the wild w/ Supermicro workaround IANA number 47488 */
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DT_BASE       43707
 #define IPMI_SUPERMICRO_PRODUCT_ID_X8DTH           IPMI_SUPERMICRO_PRODUCT_ID_X8DT_BASE
@@ -248,7 +253,7 @@ extern "C" {
 #define IPMI_SUPERMICRO_PRODUCT_ID_X9SCM_IIF   1600
 
 /* Seen in the wild w/ Magnum Technologies IANA number 5593 */
-/* defined above: IPMI_SUPERMICRO_PRODUCT_ID_X8DTL */
+#define IPMI_SUPERMICRO_PRODUCT_ID_MAGNUM_TECHNOLOGIES_X8DTL IPMI_SUPERMICRO_PRODUCT_ID_X8DTL
 
 /******************************************* 
  * Wistron                                 *
